from distutils.core import setup

setup (
	name		= "mageNum",
	version		= "1.0.0",
	py_modules	= [ "mageNum" ],
	author		= "zjypython",
	author_email	= "hy930626@outlook.com", 
	url		= "http://www.headfirstlabs.com",
	description	= "A simple printer of mageNum",
           )